@@ -564,3 +564,37 @@ class NetSuiteClient:
     #             has_failures = True
     #             raise exc
     #     return record_refs
+
+    def delete(self, recordType, internalId=None, externalId=None):
+        """
+        Make a delete request to remove an object of type recordType
+        specified by either internalId or externalId
+
+        :param str recordType: the complex type (e.g. 'vendor')
+        :param int internalId: id specifying the record to be deleted
+        :param str externalId: str specifying the record to be deleted
+        :return: a reference to the deleted record (in case of success)
+        :rtype: RecordRef
+        :raises ValueError: if neither internalId nor externalId was passed
+        """
+
+        recordType = recordType[0].lower() + recordType[1:]
+        if internalId is not None:
+            record_ref = self.RecordRef(type=recordType, internalId=internalId)
+        elif externalId is not None:
+            record_ref = self.RecordRef(type=recordType, externalId=externalId)
+        else:
+            raise ValueError('Either internalId or externalId is necessary to make a delete request.')
+
+        response = self.request('delete', baseRef=record_ref)
+        response = response.body.writeResponse
+        status = response.status
+        if status.isSuccess:
+            record_ref = response['baseRef']
+            self.logger.debug(
+                'Successfully deleted record of internalId: {internalId}, externalId: {externalId}, response: {recordRef}'.format(
+                     internalId=record_ref['internalId'], externalId=record_ref['externalId'], recordRef=record_ref))
+            return record_ref
+        else:
+            exc = self._request_error('delete', detail=status['statusDetail'][0])
+            raise exc
